@@ -12,7 +12,7 @@ class Normalizer():
 		self._punctuation_spacing = punctuation_spacing
 		self._affix_spacing = affix_spacing
 
-		self.translations = maketrans(' كي;%1234567890', ' کی؛٪۱۲۳۴۵۶۷۸۹۰')
+		self.translations = maketrans(' كي%1234567890;“”', ' کی٪۱۲۳۴۵۶۷۸۹۰؛""')
 
 		punc_after, punc_before = r'!:\.،؛؟»\]\)\}', r'«\[\(\{'
 		if character_refinement:
@@ -20,8 +20,8 @@ class Normalizer():
 				(r'[ـ\r]', ''), # remove keshide, carriage returns
 				(r' +', ' '), # remove extra spaces
 				(r'\n\n+', '\n\n'), # remove extra newlines
-				('"([^"]+)"', r'«\1»'), # replace quotation with gyoome
-				('([\d+]).([\d+])', r'\1٫\2'), # replace dot with momayez
+				('"([^\n"]+)"', r'«\1»'), # replace quotation with gyoome
+				('([\d+])\.([\d+])', r'\1٫\2'), # replace dot with momayez
 				(r' ?\.\.\.', ' …'), # replace 3 dots
 			])
 
@@ -55,12 +55,16 @@ class Normalizer():
 		>>> normalizer.character_refinement('اصلاح كاف و ياي عربي')
 		'اصلاح کاف و یای عربی'
 
+		>>> normalizer.character_refinement('عراق سال 2012 قراردادی به ارزش "4.2 میلیارد دلار" برای خرید تجهیزات نظامی با روسیه امضا  کرد.')
+		'عراق سال ۲۰۱۲ قراردادی به ارزش «۴٫۲ میلیارد دلار» برای خرید تجهیزات نظامی با روسیه امضا کرد.'
+
 		>>> normalizer.character_refinement('رمــــان')
 		'رمان'
 		"""
+
+		text = text.translate(self.translations)
 		for pattern, repl in self.character_refinement_patterns:
 			text = pattern.sub(repl, text)
-		text = text.translate(self.translations)
 		return text
 
 	def punctuation_spacing(self, text):
@@ -69,7 +73,7 @@ class Normalizer():
 		'اصلاح (پرانتزها) در متن.'
 		"""
 
-		# todo: don't put space inside time and float numbers
+		# todo: don't put space inside time
 		for pattern, repl in self.punctuation_spacing_patterns:
 			text = pattern.sub(repl, text)
 		return text
