@@ -14,14 +14,14 @@ class WordTokenizer(TokenizerI):
 		if join_verb_parts:
 			self.after_verbs = set([
 				'ام', 'ای', 'است', 'ایم', 'اید', 'اند', 'بودم', 'بودی', 'بود', 'بودیم', 'بودید', 'بودند', 'باشم', 'باشی', 'باشد', 'باشیم', 'باشید', 'باشند',
-				'شده ام', 'شده ای', 'شده است', 'شده ایم', 'شده اید', 'شده اند', 'شده بودم', 'شده بودی', 'شده بود', 'شده بودیم', 'شده بودید', 'شده بودند', 'شده باشم', 'شده باشی', 'شده باشد', 'شده باشیم', 'شده باشید', 'شده باشند',
-				'نشده ام', 'نشده ای', 'نشده است', 'نشده ایم', 'نشده اید', 'نشده اند', 'نشده بودم', 'نشده بودی', 'نشده بود', 'نشده بودیم', 'نشده بودید', 'نشده بودند', 'نشده باشم', 'نشده باشی', 'نشده باشد', 'نشده باشیم', 'نشده باشید', 'نشده باشند',
+				'شده_ام', 'شده_ای', 'شده_است', 'شده_ایم', 'شده_اید', 'شده_اند', 'شده_بودم', 'شده_بودی', 'شده_بود', 'شده_بودیم', 'شده_بودید', 'شده_بودند', 'شده_باشم', 'شده_باشی', 'شده_باشد', 'شده_باشیم', 'شده_باشید', 'شده_باشند',
+				'نشده_ام', 'نشده_ای', 'نشده_است', 'نشده_ایم', 'نشده_اید', 'نشده_اند', 'نشده_بودم', 'نشده_بودی', 'نشده_بود', 'نشده_بودیم', 'نشده_بودید', 'نشده_بودند', 'نشده_باشم', 'نشده_باشی', 'نشده_باشد', 'نشده_باشیم', 'نشده_باشید', 'نشده_باشند',
 				'شوم', 'شوی', 'شود', 'شویم', 'شوید', 'شوند', 'شدم', 'شدی', 'شد', 'شدیم', 'شدید', 'شدند',
 				'نشوم', 'نشوی', 'نشود', 'نشویم', 'نشوید', 'نشوند', 'نشدم', 'نشدی', 'نشد', 'نشدیم', 'نشدید', 'نشدند',
 				'می‌شوم', 'می‌شوی', 'می‌شود', 'می‌شویم', 'می‌شوید', 'می‌شوند', 'می‌شدم', 'می‌شدی', 'می‌شد', 'می‌شدیم', 'می‌شدید', 'می‌شدند',
 				'نمی‌شوم', 'نمی‌شوی', 'نمی‌شود', 'نمی‌شویم', 'نمی‌شوید', 'نمی‌شوند', 'نمی‌شدم', 'نمی‌شدی', 'نمی‌شد', 'نمی‌شدیم', 'نمی‌شدید', 'نمی‌شدند',
-				'خواهم شد', 'خواهی شد', 'خواهد شد', 'خواهیم شد', 'خواهید شد', 'خواهند شد',
-				'نخواهم شد', 'نخواهی شد', 'نخواهد شد', 'نخواهیم شد', 'نخواهید شد', 'نخواهند شد',
+				'خواهم_شد', 'خواهی_شد', 'خواهد_شد', 'خواهیم_شد', 'خواهید_شد', 'خواهند_شد',
+				'نخواهم_شد', 'نخواهی_شد', 'نخواهد_شد', 'نخواهیم_شد', 'نخواهید_شد', 'نخواهند_شد',
 			])
 
 			self.before_verbs = set([
@@ -29,8 +29,10 @@ class WordTokenizer(TokenizerI):
 				'نخواهم', 'نخواهی', 'نخواهد', 'نخواهیم', 'نخواهید', 'نخواهند'
 			])
 
-			self.verbs = list(reversed([verb.strip() for verb in codecs.open(verbs_file, encoding='utf8') if verb]))
-			self.verbe = set([verb.split('#')[0] + 'ه' for verb in self.verbs])
+			with codecs.open(verbs_file, encoding='utf8') as verbs_file:
+				self.verbs = list(reversed([verb.strip() for verb in verbs_file if verb]))
+				self.bons = set([verb.split('#')[0] for verb in self.verbs])
+				self.verbe = set([bon +'ه' for bon in self.bons] + ['ن'+ bon +'ه' for bon in self.bons])
 
 	def tokenize(self, text):
 		"""
@@ -38,7 +40,7 @@ class WordTokenizer(TokenizerI):
 		['این', 'جمله', '(', 'خیلی', ')', 'پیچیده', 'نیست', '!!!']
 		"""
 
-		text = self.pattern.sub(r' \1 ', text)
+		text = self.pattern.sub(r' \1 ', text.replace('\n', ' '))
 		tokens = [word for word in text.split(' ') if word]
 		if self._join_verb_parts:
 			tokens = self.join_verb_parts(tokens)
@@ -47,13 +49,13 @@ class WordTokenizer(TokenizerI):
 	def join_verb_parts(self, tokens):
 		"""
 		>>> word_tokenizer.join_verb_parts(['خواهد', 'رفت'])
-		['خواهد رفت']
+		['خواهد_رفت']
 		>>> word_tokenizer.join_verb_parts(['رفته', 'است'])
-		['رفته است']
+		['رفته_است']
 		>>> word_tokenizer.join_verb_parts(['گفته', 'شده', 'است'])
-		['گفته شده است']
+		['گفته_شده_است']
 		>>> word_tokenizer.join_verb_parts(['گفته', 'خواهد', 'شد'])
-		['گفته خواهد شد']
+		['گفته_خواهد_شد']
 		>>> word_tokenizer.join_verb_parts(['خسته', 'شدید'])
 		['خسته', 'شدید']
 		"""
@@ -61,7 +63,7 @@ class WordTokenizer(TokenizerI):
 		result = ['']
 		for token in reversed(tokens):
 			if token in self.before_verbs or (result[-1] in self.after_verbs and token in self.verbe):
-				result[-1] = token +' '+ result[-1]
+				result[-1] = token +'_'+ result[-1]
 			else:
 				result.append(token)
 		return list(reversed(result[1:]))
