@@ -1,11 +1,12 @@
 
+from .WordTokenizer import WordTokenizer
+from .SentenceTokenizer import SentenceTokenizer
 from .PeykareReader import PeykareReader
 from .BijankhanReader import BijankhanReader
 from .HamshahriReader import HamshahriReader
+from .VerbValencyReader import VerbValencyReader
 from .DadeganReader import DadeganReader
 from .TreebankReader import TreebankReader
-from .SentenceTokenizer import SentenceTokenizer
-from .WordTokenizer import WordTokenizer
 from .Normalizer import Normalizer
 from .Stemmer import Stemmer
 from .Lemmatizer import Lemmatizer
@@ -13,7 +14,14 @@ from .POSTagger import POSTagger
 from .Chunker import Chunker
 from .DependencyParser import DependencyParser
 
-sentence_tokenizer = SentenceTokenizer()
-sent_tokenize = lambda text: sentence_tokenizer.tokenize(text)
-word_tokenizer = WordTokenizer()
-word_tokenize = lambda text: word_tokenizer.tokenize(text)
+
+def sent_tokenize(text):
+	if not hasattr(sent_tokenize, 'tokenizer'):
+		sent_tokenize.tokenizer = SentenceTokenizer()
+	return sent_tokenize.tokenizer.tokenize(text)
+
+
+def word_tokenize(sentence):
+	if not hasattr(word_tokenize, 'tokenizer'):
+		word_tokenize.tokenizer = WordTokenizer()
+	return word_tokenize.tokenizer.tokenize(sentence)
